# Parser

::: riweather.parser.ISDRecord

::: riweather.parser.ControlData
::: riweather.parser.MandatoryData
::: riweather.parser.AdditionalData
::: riweather.parser.WindObservation
::: riweather.parser.SkyConditionObservation
::: riweather.parser.VisibilityObservation
::: riweather.parser.AirTemperatureObservation
::: riweather.parser.AtmosphericPressureObservation
